@@ -53,6 +53,7 @@
 // Bound library includes
 #include <Qt3DCore/qbackendnode.h>
 #include <Qt3DCore/qaspectjob.h>
+#include <Qt3DCore/qcoresettings.h>
 #include <Qt3DCore/qgeometry.h>
 #include <Qt3DCore/qabstractaspect.h>
 #include <Qt3DCore/qarmature.h>
@@ -103,24 +104,26 @@ enum : int {
     SBK_QT3DCORE_QATTRIBUTE_IDX                              = 9,
     SBK_QT3DCORE_QBACKENDNODE_MODE_IDX                       = 13,
     SBK_QT3DCORE_QBACKENDNODE_IDX                            = 12,
-    SBK_QT3DCORE_QBOUNDINGVOLUME_IDX                         = 14,
-    SBK_QT3DCORE_QBUFFER_USAGETYPE_IDX                       = 17,
-    SBK_QT3DCORE_QBUFFER_ACCESSTYPE_IDX                      = 16,
-    SBK_QT3DCORE_QBUFFER_IDX                                 = 15,
-    SBK_QT3DCORE_QCOMPONENT_IDX                              = 18,
-    SBK_QT3DCORE_QENTITY_IDX                                 = 19,
-    SBK_QT3DCORE_QGEOMETRY_IDX                               = 20,
-    SBK_QT3DCORE_QGEOMETRYVIEW_PRIMITIVETYPE_IDX             = 22,
-    SBK_QT3DCORE_QGEOMETRYVIEW_IDX                           = 21,
-    SBK_QT3DCORE_QJOINT_IDX                                  = 23,
-    SBK_QT3DCORE_QNODE_IDX                                   = 24,
-    SBK_QT3DCORE_QNODEID_IDX                                 = 25,
-    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 26,
-    SBK_QT3DCORE_QSKELETON_IDX                               = 27,
-    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 29,
-    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 28,
-    SBK_QT3DCORE_QTRANSFORM_IDX                              = 30,
-    SBK_Qt3DCore_IDX_COUNT                                   = 31
+    SBK_QT3DCORE_QBACKENDNODEMAPPER_IDX                      = 14,
+    SBK_QT3DCORE_QBOUNDINGVOLUME_IDX                         = 15,
+    SBK_QT3DCORE_QBUFFER_USAGETYPE_IDX                       = 18,
+    SBK_QT3DCORE_QBUFFER_ACCESSTYPE_IDX                      = 17,
+    SBK_QT3DCORE_QBUFFER_IDX                                 = 16,
+    SBK_QT3DCORE_QCOMPONENT_IDX                              = 19,
+    SBK_QT3DCORE_QCORESETTINGS_IDX                           = 20,
+    SBK_QT3DCORE_QENTITY_IDX                                 = 21,
+    SBK_QT3DCORE_QGEOMETRY_IDX                               = 22,
+    SBK_QT3DCORE_QGEOMETRYVIEW_PRIMITIVETYPE_IDX             = 24,
+    SBK_QT3DCORE_QGEOMETRYVIEW_IDX                           = 23,
+    SBK_QT3DCORE_QJOINT_IDX                                  = 25,
+    SBK_QT3DCORE_QNODE_IDX                                   = 26,
+    SBK_QT3DCORE_QNODEID_IDX                                 = 27,
+    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 28,
+    SBK_QT3DCORE_QSKELETON_IDX                               = 29,
+    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 31,
+    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 30,
+    SBK_QT3DCORE_QTRANSFORM_IDX                              = 32,
+    SBK_Qt3DCore_IDX_COUNT                                   = 33
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DCoreTypes;
@@ -167,11 +170,13 @@ template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAttribute::VertexBaseType
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAttribute >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QATTRIBUTE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBackendNode::Mode >() { return SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBACKENDNODE_MODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBackendNode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBACKENDNODE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBackendNodeMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBACKENDNODEMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBoundingVolume >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBOUNDINGVOLUME_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBuffer::UsageType >() { return SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBUFFER_USAGETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBuffer::AccessType >() { return SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBUFFER_ACCESSTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBuffer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QBUFFER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QComponent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QCOMPONENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DCore::QCoreSettings >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QCORESETTINGS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QEntity >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QGeometry >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QGEOMETRY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QGeometryView::PrimitiveType >() { return SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QGEOMETRYVIEW_PRIMITIVETYPE_IDX]; }
