@@ -135,7 +135,7 @@ extern SbkConverter **SbkPySide6_Qt3DInputTypeConverters;
 // Converter indices
 enum : int {
     SBK_QT3DINPUT_QLIST_QT3DCORE_QENTITYPTR_IDX              = 0, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DINPUT_QLIST_QOBJECTPTR_IDX                       = 1, // const QList<QObject* > &
+    SBK_QT3DINPUT_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
     SBK_QT3DINPUT_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
     SBK_QT3DINPUT_QLIST_QT3DINPUT_QACTIONPTR_IDX             = 3, // QList<Qt3DInput::QAction* >
     SBK_QT3DINPUT_QLIST_QT3DINPUT_QAXISPTR_IDX               = 4, // QList<Qt3DInput::QAxis* >
