@@ -58,6 +58,7 @@
 #include <QtDesigner/abstractformwindowcursor.h>
 #include <QtDesigner/propertysheet.h>
 #include <QtDesigner/taskmenu.h>
+#include <QtDesigner/formbuilder.h>
 #include <QtDesigner/default_extensionfactory.h>
 #include <QtDesigner/abstractformwindow.h>
 #include <QtDesigner/dynamicpropertysheet.h>
@@ -126,12 +127,13 @@ enum : int {
     SBK_QDESIGNERWIDGETBOXINTERFACE_WIDGET_IDX               = 29,
     SBK_QEXTENSIONFACTORY_IDX                                = 31,
     SBK_QEXTENSIONMANAGER_IDX                                = 32,
-    SBK_QPYDESIGNERCONTAINEREXTENSION_IDX                    = 34,
-    SBK_QPYDESIGNERCUSTOMWIDGETCOLLECTION_IDX                = 35,
-    SBK_QPYDESIGNERMEMBERSHEETEXTENSION_IDX                  = 36,
-    SBK_QPYDESIGNERPROPERTYSHEETEXTENSION_IDX                = 37,
-    SBK_QPYDESIGNERTASKMENUEXTENSION_IDX                     = 38,
-    SBK_QtDesigner_IDX_COUNT                                 = 39
+    SBK_QFORMBUILDER_IDX                                     = 34,
+    SBK_QPYDESIGNERCONTAINEREXTENSION_IDX                    = 35,
+    SBK_QPYDESIGNERCUSTOMWIDGETCOLLECTION_IDX                = 36,
+    SBK_QPYDESIGNERMEMBERSHEETEXTENSION_IDX                  = 37,
+    SBK_QPYDESIGNERPROPERTYSHEETEXTENSION_IDX                = 38,
+    SBK_QPYDESIGNERTASKMENUEXTENSION_IDX                     = 39,
+    SBK_QtDesigner_IDX_COUNT                                 = 40
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtDesignerTypes;
@@ -197,6 +199,7 @@ template<> inline PyTypeObject *SbkType< ::QDesignerWidgetBoxInterface::Widget::
 template<> inline PyTypeObject *SbkType< ::QDesignerWidgetBoxInterface::Widget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QDESIGNERWIDGETBOXINTERFACE_WIDGET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QExtensionFactory >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QEXTENSIONFACTORY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QExtensionManager >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QEXTENSIONMANAGER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QFormBuilder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QFORMBUILDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPyDesignerContainerExtension >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QPYDESIGNERCONTAINEREXTENSION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPyDesignerCustomWidgetCollection >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QPYDESIGNERCUSTOMWIDGETCOLLECTION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPyDesignerMemberSheetExtension >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtDesignerTypes[SBK_QPYDESIGNERMEMBERSHEETEXTENSION_IDX]); }
