@@ -87,7 +87,7 @@ extern SbkConverter **SbkPySide6_QtSvgTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 0, // const QList<QObject* > &
+    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 0, // QList<QObject* >
     SBK_QTSVG_QLIST_QBYTEARRAY_IDX                           = 1, // QList<QByteArray >
     SBK_QTSVG_QLIST_QVARIANT_IDX                             = 2, // QList<QVariant >
     SBK_QTSVG_QLIST_QSTRING_IDX                              = 3, // QList<QString >
