@@ -1,32 +1,33 @@
 import os
 import sys
+from pathlib import Path
 from textwrap import dedent
 
 __all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Xml;Help;OpenGL;OpenGLFunctions;OpenGLWidgets;Qml;Quick;QuickControls2;QuickWidgets;Svg;SvgWidgets;UiTools;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
+    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;OpenGL;OpenGLWidgets;Qml;Quick;QuickControls2;QuickWidgets;Scxml;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;UiTools;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.0.1"
-__version_info__ = (6, 0, 1, "", "")
+__version__ = "6.1.2"
+__version_info__ = (6, 1, 2, "", "")
 
 
 def _additional_dll_directories(package_dir):
     # Find shiboken6 relative to the package directory.
-    root = os.path.dirname(package_dir)
+    root = Path(package_dir).parent
     # Check for a flat .zip as deployed by cx_free(PYSIDE-1257)
-    if root.endswith('.zip'):
+    if root.suffix == '.zip':
         return []
-    shiboken6 = os.path.join(root, 'shiboken6')
-    if os.path.isdir(shiboken6): # Standard case, only shiboken6 is needed
+    shiboken6 = root / 'shiboken6'
+    if shiboken6.is_dir(): # Standard case, only shiboken6 is needed
         return [shiboken6]
     # The below code is for the build process when generate_pyi.py
     # is executed in the build directory. We need libpyside and Qt in addition.
-    shiboken6 = os.path.join(os.path.dirname(root), 'shiboken6', 'libshiboken')
-    if not os.path.isdir(shiboken6):
+    shiboken6 = Path(root).parent / 'shiboken6' / 'libshiboken'
+    if not shiboken6.is_dir():
         raise ImportError(shiboken6 + ' does not exist')
-    result = [shiboken6, os.path.join(root, 'libpyside')]
+    result = [shiboken6, root / 'libpyside']
     for path in os.environ.get('PATH').split(';'):
         if path:
-             if os.path.exists(os.path.join(path, 'qmake.exe')):
+             if (Path(path) / 'qmake.exe').exists():
                  result.append(path)
                  break
     return result
@@ -47,17 +48,19 @@ def _setupQtDirectories():
     # loads the libraries into the process memory beforehand, and
     # thus takes care of it for us.
 
-    pyside_package_dir = os.path.abspath(os.path.dirname(__file__))
+    pyside_package_dir = Path(__file__).parent.resolve()
 
     if sys.platform == 'win32' and sys.version_info[0] == 3 and sys.version_info[1] >= 8:
         for dir in _additional_dll_directories(pyside_package_dir):
             os.add_dll_directory(dir)
 
     try:
-        import shiboken6
+        # PYSIDE-1497: we use the build dir or install dir or site-packages, whatever the path
+        #              setting dictates. There is no longer a difference in path structure.
+        from shiboken6 import Shiboken
     except Exception:
         paths = ', '.join(sys.path)
-        print(f"PySide6/__init__.py: Unable to import shiboken6 from {paths}",
+        print(f"PySide6/__init__.py: Unable to import Shiboken from {paths}",
               file=sys.stderr)
         raise
 
@@ -66,16 +69,17 @@ def _setupQtDirectories():
         # PYSIDE-829: Avoid non-existent attributes in compiled code (Nuitka).
         # We now use an explicit function instead of touching a signature.
         _init_pyside_extension()
-    except AttributeError:
+    except (AttributeError, NameError):
         stars = 79 * "*"
+        fname = Shiboken.__file__
         print(dedent(f'''\
             {stars}
             PySide6/__init__.py: The `signature` module was not initialized.
             This libshiboken module was loaded from
 
-            "{shiboken6.__file__}".
+            "{fname}".
 
-            Please make sure that this is the real shiboken6 binary and not just a folder.
+            Please make sure that this is the real Shiboken binary and not just a folder.
             {stars}
             '''), file=sys.stderr)
         raise
@@ -84,17 +88,17 @@ def _setupQtDirectories():
         # PATH has to contain the package directory, otherwise plugins
         # won't be able to find their required Qt libraries (e.g. the
         # svg image plugin won't find Qt5Svg.dll).
-        os.environ['PATH'] = pyside_package_dir + os.pathsep + os.environ['PATH']
+        os.environ['PATH'] = os.fspath(pyside_package_dir) + os.pathsep + os.environ['PATH']
 
         # On Windows, add the PySide6\openssl folder (created by setup.py's
         # --openssl option) to the PATH so that the SSL DLLs can be found
         # when Qt tries to dynamically load them. Tell Qt to load them and
         # then reset the PATH.
-        openssl_dir = os.path.join(pyside_package_dir, 'openssl')
-        if os.path.exists(openssl_dir):
+        openssl_dir = pyside_package_dir / 'openssl'
+        if openssl_dir.exists():
             path = os.environ['PATH']
             try:
-                os.environ['PATH'] = openssl_dir + os.pathsep + path
+                os.environ['PATH'] = os.fspath(openssl_dir) + os.pathsep + path
                 try:
                     from . import QtNetwork
                 except ImportError:
